/*                                                                            */

/*----------------------------------------------------------------------------*/
/* System Includes                                                            */
/*----------------------------------------------------------------------------*/

	#include <clib/alib_protos.h>
	#include <proto/exec.h>
	#include <proto/dos.h>
	#include <proto/graphics.h>
	#include <proto/intuition.h>
	#include <proto/utility.h>
	#include <intuition/gadgetclass.h>
	#include <intuition/imageclass.h>
	#include <intuition/classusr.h>
	#include <reaction/reaction.h>
	#include <reaction/reaction_macros.h>

	#include <proto/window.h>
	#include <clib/window_protos.h>
	#include <classes/window.h>

	#include <proto/layout.h>
	#include <clib/layout_protos.h>
	#include <gadgets/layout.h>

	#include <proto/button.h>
	#include <clib/button_protos.h>
	#include <gadgets/button.h>

	#include <proto/bitmap.h>
	#include <clib/bitmap_protos.h>
	#include <images/bitmap.h>

/*----------------------------------------------------------------------------*/
/* Konstanten und Makros                                                      */
/*----------------------------------------------------------------------------*/

	#define GID_NEXT 1
	#define GID_PREV 2
	#define GID_END  3


#ifdef __amigaos4__
	#define BASEDEF(base) struct Library *base##Base = NULL; struct base##IFace *I##base = NULL
	#define OPENLIB(base,name) if (!(base##Base = OpenLibrary (name,0)) || !(I##base = (struct base##IFace *)GetInterface ((struct Library *)base##Base,"main",1,NULL))) ok = FALSE
	#define CLOSELIB(base) if (I##base) DropInterface ((struct Interface *)I##base); if (base##Base) CloseLibrary (base##Base)
#else
	#define BASEDEF(base) struct Library *base##Base = NULL
	#define OPENLIB(base,name) if (!(base##Base = OpenLibrary (name,0))) ok = FALSE
	#define CLOSELIB(base) if (base##Base) CloseLibrary (base##Base)
#endif

/*----------------------------------------------------------------------------*/
/* Type definitions                                                           */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Globale Variablen                                                          */
/*----------------------------------------------------------------------------*/

	BASEDEF(Window);
	BASEDEF(Layout);
	BASEDEF(Button);
	BASEDEF(BitMap);

	char *piclist[] = {
		"SYS:Prefs/Presets/Patterns/Bricks/BricksBlue.brush",
		"SYS:Prefs/Presets/Patterns/Brushed/BrushedGrey.brush",
		"SYS:Prefs/Presets/Patterns/Chalk/ChalkGreen.brush",
		"SYS:Prefs/Presets/Patterns/Bumpy/BumpyBlue.brush",
		NULL};

/*----------------------------------------------------------------------------*/
/*                                                                            */
/*----------------------------------------------------------------------------*/

	BOOL open_libs (void)

	{
	BOOL ok = TRUE;

	OPENLIB(Window,"window.class");
	OPENLIB(Layout,"gadgets/layout.gadget");
	OPENLIB(Button,"gadgets/button.gadget");
	OPENLIB(BitMap,"images/bitmap.image");

	return (ok);
	}

/*----------------------------------------------------------------------------*/
/*                                                                            */
/*----------------------------------------------------------------------------*/

	void close_libs (void)

	{
	CLOSELIB(Window);
	CLOSELIB(Layout);
	CLOSELIB(Button);
	CLOSELIB(BitMap);
	}

/*----------------------------------------------------------------------------*/
/* Hauptprogramm                                                              */
/*----------------------------------------------------------------------------*/

	int main (void)

	{
	Object *winobj;
	struct Screen *scr;
	struct Window *win;
	ULONG winsig,sigs;
	BOOL cont;
	ULONG result;
	struct Image *bmobj,*bmnew;
	struct Gadget *buttonobj;
	struct Gadget *rootlayout;
	long picnum = 0;


	if (!open_libs())
		{
		Printf ("cannot open required BOOPSI classes\n");
		close_libs();
		return (20);
		}

	if (scr = LockPubScreen (NULL))
		{
		bmobj = BitMapObject,
			BITMAP_Screen,scr,
			BITMAP_SourceFile,piclist[picnum],
		EndObject;

		if (winobj = WindowObject,
				WA_CustomScreen,scr,
				WA_Title,"ReAct",
				WA_Flags,WFLG_CLOSEGADGET|WFLG_DRAGBAR|WFLG_DEPTHGADGET|WFLG_SIZEBBOTTOM|WFLG_SIZEGADGET|WFLG_ACTIVATE,
			//	WA_Width,scr->Width / 2,
			//	WA_Height,scr->Height / 2,
				WINDOW_Position,WPOS_CENTERSCREEN,
				WINDOW_ParentGroup,rootlayout = VGroupObject,
					StartHGroup,
						LAYOUT_SpaceOuter,TRUE,
						LAYOUT_AddChild,buttonobj = ButtonObject,
							GA_ReadOnly,TRUE,
							BUTTON_BevelStyle,BVS_NONE,
							BUTTON_Transparent,TRUE,
							BUTTON_RenderImage,bmobj,
						EndObject,
					EndHGroup,
					StartHGroup,
						LAYOUT_SpaceOuter,TRUE,
						LAYOUT_FixedVert,FALSE,
						LAYOUT_EvenSize,TRUE,
						LAYOUT_AddChild,
							Button("Vor",GID_NEXT),
						LAYOUT_AddChild,
							Button("Zurck",GID_PREV),
						LAYOUT_AddChild,
							Button("Ende",GID_END),
					EndHGroup,
				EndVGroup,
			EndWindow)
			{

			if (win = RA_OpenWindow ((Object *)winobj))
				{

				GetAttr (WINDOW_SigMask, winobj, &winsig);

				cont = TRUE;
				do	{
					sigs = Wait (winsig | SIGBREAKF_CTRL_C);
					if (sigs & SIGBREAKF_CTRL_C)
						cont = FALSE;
					if (sigs & winsig)
						while ((result = RA_HandleInput ((Object *)winobj, NULL)) != WMHI_LASTMSG)
							{
							switch (result & WMHI_CLASSMASK)
								{
							case WMHI_GADGETUP:
								switch (result & WMHI_GADGETMASK)
									{
								case GID_NEXT:
									picnum++;
									if (!piclist[picnum])
										picnum = 0;
									if (bmnew = BitMapObject,
											BITMAP_Screen,scr,
											BITMAP_SourceFile,piclist[picnum],
										EndObject)
										{
										SetAttrs (buttonobj,BUTTON_RenderImage,bmnew,TAG_END);
										DoMethod (winobj,WM_RETHINK);
										if (bmobj)
											DisposeObject (bmobj);
										bmobj = bmnew;
										}
									break;
								case GID_PREV:
									picnum--;
									if (picnum < 0)
										{
										for (picnum = 0; piclist[picnum]; picnum++);
										picnum --;
										}
									if (bmnew = BitMapObject,
											BITMAP_Screen,scr,
											BITMAP_SourceFile,piclist[picnum],
										EndObject)
										{
										SetAttrs (buttonobj,BUTTON_RenderImage,bmnew,TAG_END);
										DoMethod (winobj,WM_RETHINK);
										if (bmobj)
											DisposeObject (bmobj);
										bmobj = bmnew;
										}
									break;
								case GID_END:
									cont = FALSE;
									break;
									}
								break;
							case WMHI_CLOSEWINDOW:
								cont = FALSE;
								break;
							default:
								break;
								}
							}
					}
				while (cont);
				}

			DisposeObject (winobj);
			}

		if (bmobj)
			DisposeObject (bmobj);

		UnlockPubScreen (NULL,scr);
		}

	close_libs();

	return (0);
	}

/*----------------------------------------------------------------------------*/
/* Ende des Quelltextes                                                       */
/*----------------------------------------------------------------------------*/
